"""Manipulate, verify and de/serialize Asset Administration Shells."""

# Synchronize with __init__.py and changelog.rst!
__version__ = "1.1.4"
__author__ = "Marko Ristin"
__copyright__ = "2024 Contributors to aas-core3.0-python"
__license__ = "License :: OSI Approved :: MIT License"
__status__ = "Production/Stable"
